/*      */ package org.apache.batik.transcoder;
/*      */ 
/*      */ import java.awt.Dimension;
/*      */ import java.awt.geom.AffineTransform;
/*      */ import java.awt.geom.Dimension2D;
/*      */ import java.awt.geom.Rectangle2D;
/*      */ import java.util.LinkedList;
/*      */ import java.util.List;
/*      */ import java.util.StringTokenizer;
/*      */ import org.apache.batik.bridge.BaseScriptingEnvironment;
/*      */ import org.apache.batik.bridge.BridgeContext;
/*      */ import org.apache.batik.bridge.BridgeException;
/*      */ import org.apache.batik.bridge.DefaultScriptSecurity;
/*      */ import org.apache.batik.bridge.GVTBuilder;
/*      */ import org.apache.batik.bridge.NoLoadScriptSecurity;
/*      */ import org.apache.batik.bridge.RelaxedScriptSecurity;
/*      */ import org.apache.batik.bridge.SVGUtilities;
/*      */ import org.apache.batik.bridge.ScriptSecurity;
/*      */ import org.apache.batik.bridge.UserAgent;
/*      */ import org.apache.batik.bridge.UserAgentAdapter;
/*      */ import org.apache.batik.bridge.ViewBox;
/*      */ import org.apache.batik.bridge.svg12.SVG12BridgeContext;
/*      */ import org.apache.batik.dom.svg.SAXSVGDocumentFactory;
/*      */ import org.apache.batik.dom.svg.SVGDOMImplementation;
/*      */ import org.apache.batik.dom.svg.SVGOMDocument;
/*      */ import org.apache.batik.dom.util.DOMUtilities;
/*      */ import org.apache.batik.dom.util.DocumentFactory;
/*      */ import org.apache.batik.gvt.CanvasGraphicsNode;
/*      */ import org.apache.batik.gvt.CompositeGraphicsNode;
/*      */ import org.apache.batik.gvt.GraphicsNode;
/*      */ import org.apache.batik.transcoder.keys.BooleanKey;
/*      */ import org.apache.batik.transcoder.keys.FloatKey;
/*      */ import org.apache.batik.transcoder.keys.LengthKey;
/*      */ import org.apache.batik.transcoder.keys.Rectangle2DKey;
/*      */ import org.apache.batik.transcoder.keys.StringKey;
/*      */ import org.apache.batik.util.ParsedURL;
/*      */ import org.w3c.dom.DOMImplementation;
/*      */ import org.w3c.dom.Document;
/*      */ import org.w3c.dom.svg.SVGSVGElement;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public abstract class SVGAbstractTranscoder
/*      */   extends XMLAbstractTranscoder
/*      */ {
/*      */   public static final String DEFAULT_DEFAULT_FONT_FAMILY = "Arial, Helvetica, sans-serif";
/*      */   protected Rectangle2D curAOI;
/*      */   protected AffineTransform curTxf;
/*      */   protected GraphicsNode root;
/*      */   protected BridgeContext ctx;
/*      */   protected GVTBuilder builder;
/*      */   protected float width;
/*      */   protected float height;
/*      */   protected UserAgent userAgent;
/*      */   
/*      */   protected SVGAbstractTranscoder() {
/*  111 */     this.width = 400.0F; this.height = 400.0F;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  117 */     this.userAgent = createUserAgent();
/*      */     
/*  119 */     this.hints.put(XMLAbstractTranscoder.KEY_DOCUMENT_ELEMENT_NAMESPACE_URI, "http://www.w3.org/2000/svg");
/*      */     
/*  121 */     this.hints.put(XMLAbstractTranscoder.KEY_DOCUMENT_ELEMENT, "svg");
/*      */     
/*  123 */     this.hints.put(XMLAbstractTranscoder.KEY_DOM_IMPLEMENTATION, SVGDOMImplementation.getDOMImplementation());
/*      */     
/*  125 */     this.hints.put(KEY_MEDIA, "screen");
/*      */     
/*  127 */     this.hints.put(KEY_DEFAULT_FONT_FAMILY, "Arial, Helvetica, sans-serif");
/*      */     
/*  129 */     this.hints.put(KEY_EXECUTE_ONLOAD, Boolean.FALSE);
/*      */     
/*  131 */     this.hints.put(KEY_ALLOWED_SCRIPT_TYPES, "text/ecmascript, application/ecmascript, text/javascript, application/javascript, application/java-archive");
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  137 */   protected UserAgent createUserAgent() { return new SVGAbstractTranscoderUserAgent(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  150 */   protected DocumentFactory createDocumentFactory(DOMImplementation domImpl, String parserClassname) { return new SAXSVGDocumentFactory(parserClassname); }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void transcode(TranscoderInput input, TranscoderOutput output) throws TranscoderException {
/*  156 */     super.transcode(input, output);
/*      */     
/*  158 */     if (this.ctx != null) {
/*  159 */       this.ctx.dispose();
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void transcode(Document document, String uri, TranscoderOutput output) throws TranscoderException {
/*      */     AffineTransform affineTransform;
/*      */     GraphicsNode gvtRoot;
/*  174 */     if (document != null && !(document.getImplementation() instanceof SVGDOMImplementation)) {
/*      */ 
/*      */       
/*  177 */       DOMImplementation impl = (DOMImplementation)this.hints.get(XMLAbstractTranscoder.KEY_DOM_IMPLEMENTATION);
/*      */       
/*  179 */       document = DOMUtilities.deepCloneDocument(document, impl);
/*  180 */       if (uri != null) {
/*  181 */         ParsedURL url = new ParsedURL(uri);
/*  182 */         ((SVGOMDocument)document).setParsedURL(url);
/*      */       } 
/*      */     } 
/*      */     
/*  186 */     if (this.hints.containsKey(KEY_WIDTH))
/*  187 */       this.width = ((Float)this.hints.get(KEY_WIDTH)).floatValue(); 
/*  188 */     if (this.hints.containsKey(KEY_HEIGHT)) {
/*  189 */       this.height = ((Float)this.hints.get(KEY_HEIGHT)).floatValue();
/*      */     }
/*      */     
/*  192 */     SVGOMDocument svgDoc = (SVGOMDocument)document;
/*  193 */     SVGSVGElement root = svgDoc.getRootElement();
/*  194 */     this.ctx = createBridgeContext(svgDoc);
/*      */ 
/*      */     
/*  197 */     this.builder = new GVTBuilder();
/*      */     
/*  199 */     boolean isDynamic = (this.hints.containsKey(KEY_EXECUTE_ONLOAD) && ((Boolean)this.hints.get(KEY_EXECUTE_ONLOAD)).booleanValue());
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     try {
/*  205 */       if (isDynamic) {
/*  206 */         this.ctx.setDynamicState(2);
/*      */       }
/*  208 */       gvtRoot = this.builder.build(this.ctx, svgDoc);
/*      */ 
/*      */       
/*  211 */       if (this.ctx.isDynamic()) {
/*      */         
/*  213 */         BaseScriptingEnvironment se = new BaseScriptingEnvironment(this.ctx);
/*  214 */         se.loadScripts();
/*  215 */         se.dispatchSVGLoadEvent();
/*  216 */         if (this.hints.containsKey(KEY_SNAPSHOT_TIME)) {
/*  217 */           float t = ((Float)this.hints.get(KEY_SNAPSHOT_TIME)).floatValue();
/*      */           
/*  219 */           this.ctx.getAnimationEngine().setCurrentTime(t);
/*  220 */         } else if (this.ctx.isSVG12()) {
/*  221 */           float t = SVGUtilities.convertSnapshotTime(root, null);
/*  222 */           this.ctx.getAnimationEngine().setCurrentTime(t);
/*      */         } 
/*      */       } 
/*      */     } catch (BridgeException ex) {
/*  226 */       ex.printStackTrace();
/*  227 */       throw new TranscoderException(ex);
/*      */     } 
/*      */ 
/*      */     
/*  231 */     float docWidth = (float)this.ctx.getDocumentSize().getWidth();
/*  232 */     float docHeight = (float)this.ctx.getDocumentSize().getHeight();
/*      */     
/*  234 */     setImageSize(docWidth, docHeight);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  240 */     if (this.hints.containsKey(KEY_AOI)) {
/*  241 */       Rectangle2D aoi = (Rectangle2D)this.hints.get(KEY_AOI);
/*      */       
/*  243 */       affineTransform = new AffineTransform();
/*  244 */       double sx = this.width / aoi.getWidth();
/*  245 */       double sy = this.height / aoi.getHeight();
/*  246 */       double scale = Math.min(sx, sy);
/*  247 */       affineTransform.scale(scale, scale);
/*  248 */       double tx = -aoi.getX() + (this.width / scale - aoi.getWidth()) / 2.0D;
/*  249 */       double ty = -aoi.getY() + (this.height / scale - aoi.getHeight()) / 2.0D;
/*  250 */       affineTransform.translate(tx, ty);
/*      */ 
/*      */       
/*  253 */       this.curAOI = aoi;
/*      */     } else {
/*  255 */       String ref = (new ParsedURL(uri)).getRef();
/*      */ 
/*      */ 
/*      */       
/*  259 */       String viewBox = root.getAttributeNS(null, "viewBox");
/*      */ 
/*      */       
/*  262 */       if (ref != null && ref.length() != 0) {
/*  263 */         affineTransform = ViewBox.getViewTransform(ref, root, this.width, this.height, this.ctx);
/*  264 */       } else if (viewBox != null && viewBox.length() != 0) {
/*  265 */         String aspectRatio = root.getAttributeNS(null, "preserveAspectRatio");
/*      */         
/*  267 */         affineTransform = ViewBox.getPreserveAspectRatioTransform(root, viewBox, aspectRatio, this.width, this.height, this.ctx);
/*      */       
/*      */       }
/*      */       else {
/*      */         
/*  272 */         float xscale = this.width / docWidth;
/*  273 */         float yscale = this.height / docHeight;
/*  274 */         float scale = Math.min(xscale, yscale);
/*  275 */         affineTransform = AffineTransform.getScaleInstance(scale, scale);
/*      */       } 
/*      */       
/*  278 */       this.curAOI = new Rectangle2D.Float(0.0F, 0.0F, this.width, this.height);
/*      */     } 
/*      */     
/*  281 */     CanvasGraphicsNode cgn = getCanvasGraphicsNode(gvtRoot);
/*  282 */     if (cgn != null) {
/*  283 */       cgn.setViewingTransform(affineTransform);
/*  284 */       this.curTxf = new AffineTransform();
/*      */     } else {
/*  286 */       this.curTxf = affineTransform;
/*      */     } 
/*      */     
/*  289 */     this.root = gvtRoot;
/*      */   }
/*      */   
/*      */   protected CanvasGraphicsNode getCanvasGraphicsNode(GraphicsNode gn) {
/*  293 */     if (!(gn instanceof CompositeGraphicsNode))
/*  294 */       return null; 
/*  295 */     CompositeGraphicsNode cgn = (CompositeGraphicsNode)gn;
/*  296 */     List children = cgn.getChildren();
/*  297 */     if (children.size() == 0)
/*  298 */       return null; 
/*  299 */     gn = (GraphicsNode)children.get(0);
/*  300 */     if (!(gn instanceof CanvasGraphicsNode))
/*  301 */       return null; 
/*  302 */     return (CanvasGraphicsNode)gn;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  313 */   protected BridgeContext createBridgeContext(SVGOMDocument doc) { return createBridgeContext(doc.isSVG12() ? "1.2" : "1.x"); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  324 */   protected BridgeContext createBridgeContext() { return createBridgeContext("1.x"); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected BridgeContext createBridgeContext(String svgVersion) {
/*  334 */     if ("1.2".equals(svgVersion)) {
/*  335 */       return new SVG12BridgeContext(this.userAgent);
/*      */     }
/*  337 */     return new BridgeContext(this.userAgent);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void setImageSize(float docWidth, float docHeight) {
/*  351 */     float imgWidth = -1.0F;
/*  352 */     if (this.hints.containsKey(KEY_WIDTH)) {
/*  353 */       imgWidth = ((Float)this.hints.get(KEY_WIDTH)).floatValue();
/*      */     }
/*  355 */     float imgHeight = -1.0F;
/*  356 */     if (this.hints.containsKey(KEY_HEIGHT)) {
/*  357 */       imgHeight = ((Float)this.hints.get(KEY_HEIGHT)).floatValue();
/*      */     }
/*      */     
/*  360 */     if (imgWidth > 0.0F && imgHeight > 0.0F) {
/*  361 */       this.width = imgWidth;
/*  362 */       this.height = imgHeight;
/*  363 */     } else if (imgHeight > 0.0F) {
/*  364 */       this.width = docWidth * imgHeight / docHeight;
/*  365 */       this.height = imgHeight;
/*  366 */     } else if (imgWidth > 0.0F) {
/*  367 */       this.width = imgWidth;
/*  368 */       this.height = docHeight * imgWidth / docWidth;
/*      */     } else {
/*  370 */       this.width = docWidth;
/*  371 */       this.height = docHeight;
/*      */     } 
/*      */ 
/*      */     
/*  375 */     float imgMaxWidth = -1.0F;
/*  376 */     if (this.hints.containsKey(KEY_MAX_WIDTH)) {
/*  377 */       imgMaxWidth = ((Float)this.hints.get(KEY_MAX_WIDTH)).floatValue();
/*      */     }
/*  379 */     float imgMaxHeight = -1.0F;
/*  380 */     if (this.hints.containsKey(KEY_MAX_HEIGHT)) {
/*  381 */       imgMaxHeight = ((Float)this.hints.get(KEY_MAX_HEIGHT)).floatValue();
/*      */     }
/*      */     
/*  384 */     if (imgMaxHeight > 0.0F && this.height > imgMaxHeight) {
/*  385 */       this.width = docWidth * imgMaxHeight / docHeight;
/*  386 */       this.height = imgMaxHeight;
/*      */     } 
/*  388 */     if (imgMaxWidth > 0.0F && this.width > imgMaxWidth) {
/*  389 */       this.width = imgMaxWidth;
/*  390 */       this.height = docHeight * imgMaxWidth / docWidth;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  418 */   public static final TranscodingHints.Key KEY_WIDTH = new LengthKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  440 */   public static final TranscodingHints.Key KEY_HEIGHT = new LengthKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  466 */   public static final TranscodingHints.Key KEY_MAX_WIDTH = new LengthKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  492 */   public static final TranscodingHints.Key KEY_MAX_HEIGHT = new LengthKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  517 */   public static final TranscodingHints.Key KEY_AOI = new Rectangle2DKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  541 */   public static final TranscodingHints.Key KEY_LANGUAGE = new StringKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  565 */   public static final TranscodingHints.Key KEY_MEDIA = new StringKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  592 */   public static final TranscodingHints.Key KEY_DEFAULT_FONT_FAMILY = new StringKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  616 */   public static final TranscodingHints.Key KEY_ALTERNATE_STYLESHEET = new StringKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  639 */   public static final TranscodingHints.Key KEY_USER_STYLESHEET_URI = new StringKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  663 */   public static final TranscodingHints.Key KEY_PIXEL_UNIT_TO_MILLIMETER = new FloatKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  690 */   public static final TranscodingHints.Key KEY_PIXEL_TO_MM = KEY_PIXEL_UNIT_TO_MILLIMETER;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  714 */   public static final TranscodingHints.Key KEY_EXECUTE_ONLOAD = new BooleanKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  739 */   public static final TranscodingHints.Key KEY_SNAPSHOT_TIME = new FloatKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  767 */   public static final TranscodingHints.Key KEY_ALLOWED_SCRIPT_TYPES = new StringKey();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static final String DEFAULT_ALLOWED_SCRIPT_TYPES = "text/ecmascript, application/ecmascript, text/javascript, application/javascript, application/java-archive";
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  806 */   public static final TranscodingHints.Key KEY_CONSTRAIN_SCRIPT_ORIGIN = new BooleanKey();
/*      */ 
/*      */ 
/*      */   
/*      */   protected class SVGAbstractTranscoderUserAgent
/*      */     extends UserAgentAdapter
/*      */   {
/*      */     protected List scripts;
/*      */     
/*      */     private final SVGAbstractTranscoder this$0;
/*      */ 
/*      */     
/*      */     public SVGAbstractTranscoderUserAgent(SVGAbstractTranscoder this$0) {
/*  819 */       this.this$0 = this$0;
/*  820 */       addStdFeatures();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  827 */     public AffineTransform getTransform() { return this.this$0.curTxf; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  834 */     public void setTransform(AffineTransform at) { this.this$0.curTxf = at; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  841 */     public Dimension2D getViewportSize() { return new Dimension((int)this.this$0.width, (int)this.this$0.height); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void displayError(String message) {
/*      */       try {
/*  850 */         this.this$0.handler.error(new TranscoderException(message));
/*      */       } catch (TranscoderException ex) {
/*      */         
/*  853 */         throw new RuntimeException(ex.getMessage());
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void displayError(Exception e) {
/*      */       try {
/*  862 */         e.printStackTrace();
/*  863 */         this.this$0.handler.error(new TranscoderException(e));
/*      */       } catch (TranscoderException ex) {
/*      */         
/*  866 */         throw new RuntimeException(ex.getMessage());
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void displayMessage(String message) {
/*      */       try {
/*  875 */         this.this$0.handler.warning(new TranscoderException(message));
/*      */       } catch (TranscoderException ex) {
/*      */         
/*  878 */         throw new RuntimeException(ex.getMessage());
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public float getPixelUnitToMillimeter() {
/*  887 */       Object obj = this.this$0.hints.get(SVGAbstractTranscoder.KEY_PIXEL_UNIT_TO_MILLIMETER);
/*      */       
/*  889 */       if (obj != null) {
/*  890 */         return ((Float)obj).floatValue();
/*      */       }
/*      */       
/*  893 */       return super.getPixelUnitToMillimeter();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public String getLanguages() {
/*  901 */       if (this.this$0.hints.containsKey(SVGAbstractTranscoder.KEY_LANGUAGE)) {
/*  902 */         return (String)this.this$0.hints.get(SVGAbstractTranscoder.KEY_LANGUAGE);
/*      */       }
/*      */ 
/*      */       
/*  906 */       return super.getLanguages();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public String getMedia() {
/*  913 */       String s = (String)this.this$0.hints.get(SVGAbstractTranscoder.KEY_MEDIA);
/*  914 */       if (s != null) return s;
/*      */       
/*  916 */       return super.getMedia();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public String getDefaultFontFamily() {
/*  923 */       String s = (String)this.this$0.hints.get(SVGAbstractTranscoder.KEY_DEFAULT_FONT_FAMILY);
/*  924 */       if (s != null) return s;
/*      */       
/*  926 */       return super.getDefaultFontFamily();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public String getAlternateStyleSheet() {
/*  933 */       String s = (String)this.this$0.hints.get(SVGAbstractTranscoder.KEY_ALTERNATE_STYLESHEET);
/*  934 */       if (s != null) {
/*  935 */         return s;
/*      */       }
/*  937 */       return super.getAlternateStyleSheet();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public String getUserStyleSheetURI() {
/*  945 */       String s = (String)this.this$0.hints.get(SVGAbstractTranscoder.KEY_USER_STYLESHEET_URI);
/*      */       
/*  947 */       if (s != null) {
/*  948 */         return s;
/*      */       }
/*  950 */       return super.getUserStyleSheetURI();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public String getXMLParserClassName() {
/*  957 */       String s = (String)this.this$0.hints.get(XMLAbstractTranscoder.KEY_XML_PARSER_CLASSNAME);
/*      */       
/*  959 */       if (s != null) {
/*  960 */         return s;
/*      */       }
/*  962 */       return super.getXMLParserClassName();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public boolean isXMLParserValidating() {
/*  970 */       Boolean b = (Boolean)this.this$0.hints.get(XMLAbstractTranscoder.KEY_XML_PARSER_VALIDATING);
/*      */       
/*  972 */       if (b != null) {
/*  973 */         return b.booleanValue();
/*      */       }
/*  975 */       return super.isXMLParserValidating();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public ScriptSecurity getScriptSecurity(String scriptType, ParsedURL scriptPURL, ParsedURL docPURL) {
/*  994 */       if (this.scripts == null) {
/*  995 */         computeAllowedScripts();
/*      */       }
/*      */       
/*  998 */       if (!this.scripts.contains(scriptType)) {
/*  999 */         return new NoLoadScriptSecurity(scriptType);
/*      */       }
/*      */ 
/*      */       
/* 1003 */       boolean constrainOrigin = true;
/*      */       
/* 1005 */       if (this.this$0.hints.containsKey(SVGAbstractTranscoder.KEY_CONSTRAIN_SCRIPT_ORIGIN))
/*      */       {
/* 1007 */         constrainOrigin = ((Boolean)this.this$0.hints.get(SVGAbstractTranscoder.KEY_CONSTRAIN_SCRIPT_ORIGIN)).booleanValue();
/*      */       }
/*      */ 
/*      */ 
/*      */       
/* 1012 */       if (constrainOrigin) {
/* 1013 */         return new DefaultScriptSecurity(scriptType, scriptPURL, docPURL);
/*      */       }
/*      */       
/* 1016 */       return new RelaxedScriptSecurity(scriptType, scriptPURL, docPURL);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected void computeAllowedScripts() {
/* 1026 */       this.scripts = new LinkedList();
/* 1027 */       if (!this.this$0.hints.containsKey(SVGAbstractTranscoder.KEY_ALLOWED_SCRIPT_TYPES)) {
/*      */         return;
/*      */       }
/*      */ 
/*      */       
/* 1032 */       String allowedScripts = (String)this.this$0.hints.get(SVGAbstractTranscoder.KEY_ALLOWED_SCRIPT_TYPES);
/*      */ 
/*      */ 
/*      */       
/* 1036 */       StringTokenizer st = new StringTokenizer(allowedScripts, ",");
/* 1037 */       while (st.hasMoreTokens())
/* 1038 */         this.scripts.add(st.nextToken()); 
/*      */     }
/*      */   }
/*      */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-transcoder.jar!\org\apache\batik\transcoder\SVGAbstractTranscoder.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */