/*     */ package org.apache.batik.transcoder;
/*     */ 
/*     */ import java.awt.Toolkit;
/*     */ import java.io.IOException;
/*     */ import java.io.OutputStream;
/*     */ import java.io.OutputStreamWriter;
/*     */ import java.io.Writer;
/*     */ import java.net.MalformedURLException;
/*     */ import java.net.URL;
/*     */ import java.net.URLConnection;
/*     */ import org.apache.batik.dom.svg.SVGDOMImplementation;
/*     */ import org.apache.batik.svggen.SVGGraphics2D;
/*     */ import org.apache.batik.transcoder.keys.BooleanKey;
/*     */ import org.apache.batik.transcoder.keys.FloatKey;
/*     */ import org.apache.batik.transcoder.keys.IntegerKey;
/*     */ import org.apache.batik.util.SVGConstants;
/*     */ import org.w3c.dom.DOMImplementation;
/*     */ import org.w3c.dom.Document;
/*     */ import org.w3c.dom.Element;
/*     */ import org.xml.sax.XMLFilter;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class ToSVGAbstractTranscoder
/*     */   extends AbstractTranscoder
/*     */   implements SVGConstants
/*     */ {
/*  96 */   public static float PIXEL_TO_MILLIMETERS = 25.4F / Toolkit.getDefaultToolkit().getScreenResolution();
/*  97 */   public static float PIXEL_PER_INCH = Toolkit.getDefaultToolkit().getScreenResolution();
/*     */   
/*     */   public static final int TRANSCODER_ERROR_BASE = 65280;
/*     */   
/*     */   public static final int ERROR_NULL_INPUT = 65280;
/*     */   
/*     */   public static final int ERROR_INCOMPATIBLE_INPUT_TYPE = 65281;
/*     */   
/*     */   public static final int ERROR_INCOMPATIBLE_OUTPUT_TYPE = 65282;
/*     */   
/* 107 */   public static final TranscodingHints.Key KEY_WIDTH = new FloatKey();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 112 */   public static final TranscodingHints.Key KEY_HEIGHT = new FloatKey();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 117 */   public static final TranscodingHints.Key KEY_INPUT_WIDTH = new IntegerKey();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 122 */   public static final TranscodingHints.Key KEY_INPUT_HEIGHT = new IntegerKey();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 127 */   public static final TranscodingHints.Key KEY_XOFFSET = new IntegerKey();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 132 */   public static final TranscodingHints.Key KEY_YOFFSET = new IntegerKey();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 137 */   public static final TranscodingHints.Key KEY_ESCAPED = new BooleanKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGGraphics2D svgGenerator;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Document createDocument(TranscoderOutput output) {
/*     */     Document document;
/* 152 */     if (output.getDocument() == null)
/* 153 */     { DOMImplementation domImpl = SVGDOMImplementation.getDOMImplementation();
/*     */       
/* 155 */       document = domImpl.createDocument("http://www.w3.org/2000/svg", "svg", null); }
/* 156 */     else { document = output.getDocument(); }
/*     */     
/* 158 */     return document;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 165 */   public SVGGraphics2D getGraphics2D() { return this.svgGenerator; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void writeSVGToOutput(SVGGraphics2D svgGenerator, Element svgRoot, TranscoderOutput output) throws TranscoderException {
/* 175 */     Document doc = output.getDocument();
/*     */     
/* 177 */     if (doc != null) {
/*     */       return;
/*     */     }
/* 180 */     XMLFilter xmlFilter = output.getXMLFilter();
/* 181 */     if (xmlFilter != null) {
/* 182 */       this.handler.fatalError(new TranscoderException("65282"));
/*     */     }
/*     */     
/*     */     try {
/* 186 */       boolean escaped = false;
/* 187 */       if (this.hints.containsKey(KEY_ESCAPED)) {
/* 188 */         escaped = ((Boolean)this.hints.get(KEY_ESCAPED)).booleanValue();
/*     */       }
/* 190 */       OutputStream os = output.getOutputStream();
/* 191 */       if (os != null) {
/* 192 */         svgGenerator.stream(svgRoot, new OutputStreamWriter(os), false, escaped);
/*     */         
/*     */         return;
/*     */       } 
/*     */       
/* 197 */       Writer wr = output.getWriter();
/* 198 */       if (wr != null) {
/* 199 */         svgGenerator.stream(svgRoot, wr, false, escaped);
/*     */         
/*     */         return;
/*     */       } 
/*     */       
/* 204 */       String uri = output.getURI();
/* 205 */       if (uri != null) {
/*     */         try {
/* 207 */           URL url = new URL(uri);
/* 208 */           URLConnection urlCnx = url.openConnection();
/* 209 */           os = urlCnx.getOutputStream();
/* 210 */           svgGenerator.stream(svgRoot, new OutputStreamWriter(os), false, escaped);
/*     */           return;
/*     */         } catch (MalformedURLException e) {
/* 213 */           this.handler.fatalError(new TranscoderException(e));
/*     */         } catch (IOException e) {
/* 215 */           this.handler.fatalError(new TranscoderException(e));
/*     */         } 
/*     */       }
/*     */     } catch (IOException e) {
/* 219 */       throw new TranscoderException(e);
/*     */     } 
/*     */     
/* 222 */     throw new TranscoderException("65282");
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-transcoder.jar!\org\apache\batik\transcoder\ToSVGAbstractTranscoder.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */