/*     */ package org.apache.batik.transcoder.image;
/*     */ 
/*     */ import java.awt.Color;
/*     */ import java.awt.image.BufferedImage;
/*     */ import java.io.IOException;
/*     */ import java.io.OutputStream;
/*     */ import org.apache.batik.ext.awt.image.spi.ImageWriter;
/*     */ import org.apache.batik.ext.awt.image.spi.ImageWriterParams;
/*     */ import org.apache.batik.ext.awt.image.spi.ImageWriterRegistry;
/*     */ import org.apache.batik.transcoder.TranscoderException;
/*     */ import org.apache.batik.transcoder.TranscoderOutput;
/*     */ import org.apache.batik.transcoder.TranscodingHints;
/*     */ import org.apache.batik.transcoder.image.resources.Messages;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class JPEGTranscoder
/*     */   extends ImageTranscoder
/*     */ {
/*  46 */   public JPEGTranscoder() { this.hints.put(ImageTranscoder.KEY_BACKGROUND_COLOR, Color.white); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  55 */   public BufferedImage createImage(int width, int height) { return new BufferedImage(width, height, 1); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void writeImage(BufferedImage img, TranscoderOutput output) throws TranscoderException {
/*  66 */     OutputStream ostream = output.getOutputStream();
/*     */ 
/*     */ 
/*     */     
/*  70 */     ostream = new OutputStreamWrapper(ostream);
/*     */     
/*  72 */     if (ostream == null) {
/*  73 */       throw new TranscoderException(Messages.formatMessage("jpeg.badoutput", null));
/*     */     }
/*     */     
/*     */     try {
/*     */       float f;
/*     */       
/*  79 */       if (this.hints.containsKey(KEY_QUALITY)) {
/*  80 */         f = ((Float)this.hints.get(KEY_QUALITY)).floatValue();
/*     */       } else {
/*     */         
/*  83 */         TranscoderException te = new TranscoderException(Messages.formatMessage("jpeg.unspecifiedQuality", null));
/*     */         
/*  85 */         this.handler.error(te);
/*  86 */         f = 0.75F;
/*     */       } 
/*     */       
/*  89 */       ImageWriter writer = ImageWriterRegistry.getInstance().getWriterFor("image/jpeg");
/*     */       
/*  91 */       ImageWriterParams params = new ImageWriterParams();
/*  92 */       params.setJPEGQuality(f, true);
/*  93 */       float PixSzMM = this.userAgent.getPixelUnitToMillimeter();
/*  94 */       int PixSzInch = (int)(25.4D / PixSzMM + 0.5D);
/*  95 */       params.setResolution(PixSzInch);
/*  96 */       writer.writeImage(img, ostream, params);
/*  97 */       ostream.flush();
/*     */     } catch (IOException ex) {
/*  99 */       throw new TranscoderException(ex);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 127 */   public static final TranscodingHints.Key KEY_QUALITY = new QualityKey(null);
/*     */   
/*     */   private static class QualityKey
/*     */     extends TranscodingHints.Key
/*     */   {
/*     */     private QualityKey() {}
/*     */     
/*     */     public boolean isCompatibleValue(Object v) {
/* 135 */       if (v instanceof Float) {
/* 136 */         float q = ((Float)v).floatValue();
/* 137 */         return (q > 0.0F && q <= 1.0F);
/*     */       } 
/* 139 */       return false;
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static class OutputStreamWrapper
/*     */     extends OutputStream
/*     */   {
/*     */     OutputStream os;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 156 */     OutputStreamWrapper(OutputStream os) { this.os = os; }
/*     */ 
/*     */     
/*     */     public void close() {
/* 160 */       if (this.os == null)
/*     */         return;  try {
/* 162 */         this.os.close();
/*     */       } catch (IOException ioe) {
/* 164 */         this.os = null;
/*     */       } 
/*     */     }
/*     */     
/*     */     public void flush() {
/* 169 */       if (this.os == null)
/*     */         return;  try {
/* 171 */         this.os.flush();
/*     */       } catch (IOException ioe) {
/* 173 */         this.os = null;
/*     */       } 
/*     */     }
/*     */     
/*     */     public void write(byte[] b) throws IOException {
/* 178 */       if (this.os == null)
/*     */         return;  try {
/* 180 */         this.os.write(b);
/*     */       } catch (IOException ioe) {
/* 182 */         this.os = null;
/*     */       } 
/*     */     }
/*     */     
/*     */     public void write(byte[] b, int off, int len) throws IOException {
/* 187 */       if (this.os == null)
/*     */         return;  try {
/* 189 */         this.os.write(b, off, len);
/*     */       } catch (IOException ioe) {
/* 191 */         this.os = null;
/*     */       } 
/*     */     }
/*     */     
/*     */     public void write(int b) throws IOException {
/* 196 */       if (this.os == null)
/*     */         return;  try {
/* 198 */         this.os.write(b);
/*     */       } catch (IOException ioe) {
/* 200 */         this.os = null;
/*     */       } 
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-transcoder.jar!\org\apache\batik\transcoder\image\JPEGTranscoder.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */