/*     */ package org.apache.batik.transcoder.image;
/*     */ 
/*     */ import java.awt.image.BufferedImage;
/*     */ import java.awt.image.SinglePixelPackedSampleModel;
/*     */ import java.io.OutputStream;
/*     */ import org.apache.batik.bridge.UserAgent;
/*     */ import org.apache.batik.transcoder.TranscoderException;
/*     */ import org.apache.batik.transcoder.TranscoderOutput;
/*     */ import org.apache.batik.transcoder.TranscodingHints;
/*     */ import org.apache.batik.transcoder.image.resources.Messages;
/*     */ import org.apache.batik.transcoder.keys.FloatKey;
/*     */ import org.apache.batik.transcoder.keys.IntegerKey;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class PNGTranscoder
/*     */   extends ImageTranscoder
/*     */ {
/*  45 */   public PNGTranscoder() { this.hints.put(ImageTranscoder.KEY_FORCE_TRANSPARENT_WHITE, Boolean.FALSE); }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  50 */   public UserAgent getUserAgent() { return this.userAgent; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  59 */   public BufferedImage createImage(int width, int height) { return new BufferedImage(width, height, 2); }
/*     */ 
/*     */ 
/*     */   
/*     */   private WriteAdapter getWriteAdapter(String className) {
/*     */     try {
/*  65 */       Class clazz = Class.forName(className);
/*  66 */       return (WriteAdapter)clazz.newInstance();
/*     */     } catch (ClassNotFoundException e) {
/*     */       
/*  69 */       return null;
/*     */     } catch (InstantiationException e) {
/*  71 */       return null;
/*     */     } catch (IllegalAccessException e) {
/*  73 */       return null;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void writeImage(BufferedImage img, TranscoderOutput output) throws TranscoderException {
/*  86 */     OutputStream ostream = output.getOutputStream();
/*  87 */     if (ostream == null) {
/*  88 */       throw new TranscoderException(Messages.formatMessage("png.badoutput", null));
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  96 */     boolean forceTransparentWhite = false;
/*     */     
/*  98 */     if (this.hints.containsKey(ImageTranscoder.KEY_FORCE_TRANSPARENT_WHITE)) {
/*  99 */       forceTransparentWhite = ((Boolean)this.hints.get(ImageTranscoder.KEY_FORCE_TRANSPARENT_WHITE)).booleanValue();
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 104 */     if (forceTransparentWhite) {
/*     */       
/* 106 */       SinglePixelPackedSampleModel sppsm = (SinglePixelPackedSampleModel)img.getSampleModel();
/* 107 */       forceTransparentWhite(img, sppsm);
/*     */     } 
/*     */     
/* 110 */     WriteAdapter adapter = getWriteAdapter("org.apache.batik.ext.awt.image.codec.png.PNGTranscoderInternalCodecWriteAdapter");
/*     */     
/* 112 */     if (adapter == null) {
/* 113 */       adapter = getWriteAdapter("org.apache.batik.transcoder.image.PNGTranscoderImageIOWriteAdapter");
/*     */     }
/*     */     
/* 116 */     if (adapter == null) {
/* 117 */       throw new TranscoderException("Could not write PNG file because no WriteAdapter is availble");
/*     */     }
/*     */     
/* 120 */     adapter.writeImage(this, img, output);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 177 */   public static final TranscodingHints.Key KEY_GAMMA = new FloatKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 183 */   public static final float[] DEFAULT_CHROMA = { 0.3127F, 0.329F, 0.64F, 0.33F, 0.3F, 0.6F, 0.15F, 0.06F };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 213 */   public static final TranscodingHints.Key KEY_INDEXED = new IntegerKey();
/*     */   
/*     */   public static interface WriteAdapter {
/*     */     void writeImage(PNGTranscoder param1PNGTranscoder, BufferedImage param1BufferedImage, TranscoderOutput param1TranscoderOutput) throws TranscoderException;
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-transcoder.jar!\org\apache\batik\transcoder\image\PNGTranscoder.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */