/*     */ package org.apache.batik.transcoder.print;
/*     */ 
/*     */ import java.awt.Graphics;
/*     */ import java.awt.Graphics2D;
/*     */ import java.awt.RenderingHints;
/*     */ import java.awt.Shape;
/*     */ import java.awt.geom.AffineTransform;
/*     */ import java.awt.geom.Rectangle2D;
/*     */ import java.awt.print.PageFormat;
/*     */ import java.awt.print.Paper;
/*     */ import java.awt.print.Printable;
/*     */ import java.awt.print.PrinterJob;
/*     */ import java.io.File;
/*     */ import java.util.ArrayList;
/*     */ import java.util.List;
/*     */ import java.util.StringTokenizer;
/*     */ import org.apache.batik.bridge.BridgeContext;
/*     */ import org.apache.batik.ext.awt.RenderingHintsKeyExt;
/*     */ import org.apache.batik.transcoder.SVGAbstractTranscoder;
/*     */ import org.apache.batik.transcoder.Transcoder;
/*     */ import org.apache.batik.transcoder.TranscoderException;
/*     */ import org.apache.batik.transcoder.TranscoderInput;
/*     */ import org.apache.batik.transcoder.TranscoderOutput;
/*     */ import org.apache.batik.transcoder.TranscodingHints;
/*     */ import org.apache.batik.transcoder.XMLAbstractTranscoder;
/*     */ import org.apache.batik.transcoder.keys.BooleanKey;
/*     */ import org.apache.batik.transcoder.keys.LengthKey;
/*     */ import org.apache.batik.transcoder.keys.StringKey;
/*     */ import org.w3c.dom.Document;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class PrintTranscoder
/*     */   extends SVGAbstractTranscoder
/*     */   implements Printable
/*     */ {
/*     */   public static final String KEY_AOI_STR = "aoi";
/*     */   public static final String KEY_HEIGHT_STR = "height";
/*     */   public static final String KEY_LANGUAGE_STR = "language";
/*     */   public static final String KEY_MARGIN_BOTTOM_STR = "marginBottom";
/*     */   public static final String KEY_MARGIN_LEFT_STR = "marginLeft";
/*     */   public static final String KEY_MARGIN_RIGHT_STR = "marginRight";
/*     */   public static final String KEY_MARGIN_TOP_STR = "marginTop";
/*     */   public static final String KEY_PAGE_HEIGHT_STR = "pageHeight";
/*     */   public static final String KEY_PAGE_ORIENTATION_STR = "pageOrientation";
/*     */   public static final String KEY_PAGE_WIDTH_STR = "pageWidth";
/*     */   public static final String KEY_PIXEL_TO_MM_STR = "pixelToMm";
/*     */   public static final String KEY_SCALE_TO_PAGE_STR = "scaleToPage";
/*     */   public static final String KEY_SHOW_PAGE_DIALOG_STR = "showPageDialog";
/*     */   public static final String KEY_SHOW_PRINTER_DIALOG_STR = "showPrinterDialog";
/*     */   public static final String KEY_USER_STYLESHEET_URI_STR = "userStylesheet";
/*     */   public static final String KEY_WIDTH_STR = "width";
/*     */   public static final String KEY_XML_PARSER_CLASSNAME_STR = "xmlParserClassName";
/*     */   public static final String VALUE_MEDIA_PRINT = "print";
/*     */   public static final String VALUE_PAGE_ORIENTATION_LANDSCAPE = "landscape";
/*     */   public static final String VALUE_PAGE_ORIENTATION_PORTRAIT = "portrait";
/*     */   public static final String VALUE_PAGE_ORIENTATION_REVERSE_LANDSCAPE = "reverseLandscape";
/*     */   private List inputs;
/*     */   private List printedInputs;
/*     */   private int curIndex;
/*     */   private BridgeContext theCtx;
/*     */   
/*     */   public PrintTranscoder() {
/* 110 */     this.inputs = new ArrayList();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 116 */     this.printedInputs = null;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 121 */     this.curIndex = -1;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 136 */     this.hints.put(SVGAbstractTranscoder.KEY_MEDIA, "print");
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public void transcode(TranscoderInput in, TranscoderOutput out) {
/* 142 */     if (in != null) {
/* 143 */       this.inputs.add(in);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void transcode(Document document, String uri, TranscoderOutput output) throws TranscoderException {
/* 159 */     super.transcode(document, uri, output);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 164 */     this.theCtx = this.ctx;
/* 165 */     this.ctx = null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void print() {
/* 175 */     PrinterJob printerJob = PrinterJob.getPrinterJob();
/* 176 */     PageFormat pageFormat = printerJob.defaultPage();
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 181 */     Paper paper = pageFormat.getPaper();
/*     */     
/* 183 */     Float pageWidth = (Float)this.hints.get(KEY_PAGE_WIDTH);
/* 184 */     Float pageHeight = (Float)this.hints.get(KEY_PAGE_HEIGHT);
/* 185 */     if (pageWidth != null) {
/* 186 */       paper.setSize(pageWidth.floatValue(), paper.getHeight());
/*     */     }
/*     */     
/* 189 */     if (pageHeight != null) {
/* 190 */       paper.setSize(paper.getWidth(), pageHeight.floatValue());
/*     */     }
/*     */ 
/*     */     
/* 194 */     float x = 0.0F, y = 0.0F;
/* 195 */     float width = (float)paper.getWidth();
/* 196 */     float height = (float)paper.getHeight();
/*     */     
/* 198 */     Float leftMargin = (Float)this.hints.get(KEY_MARGIN_LEFT);
/* 199 */     Float topMargin = (Float)this.hints.get(KEY_MARGIN_TOP);
/* 200 */     Float rightMargin = (Float)this.hints.get(KEY_MARGIN_RIGHT);
/* 201 */     Float bottomMargin = (Float)this.hints.get(KEY_MARGIN_BOTTOM);
/*     */     
/* 203 */     if (leftMargin != null) {
/* 204 */       x = leftMargin.floatValue();
/* 205 */       width -= leftMargin.floatValue();
/*     */     } 
/* 207 */     if (topMargin != null) {
/* 208 */       y = topMargin.floatValue();
/* 209 */       height -= topMargin.floatValue();
/*     */     } 
/* 211 */     if (rightMargin != null) {
/* 212 */       width -= rightMargin.floatValue();
/*     */     }
/* 214 */     if (bottomMargin != null) {
/* 215 */       height -= bottomMargin.floatValue();
/*     */     }
/*     */     
/* 218 */     paper.setImageableArea(x, y, width, height);
/*     */     
/* 220 */     String pageOrientation = (String)this.hints.get(KEY_PAGE_ORIENTATION);
/* 221 */     if ("portrait".equalsIgnoreCase(pageOrientation)) {
/* 222 */       pageFormat.setOrientation(1);
/*     */     }
/* 224 */     else if ("landscape".equalsIgnoreCase(pageOrientation)) {
/* 225 */       pageFormat.setOrientation(0);
/*     */     }
/* 227 */     else if ("reverseLandscape".equalsIgnoreCase(pageOrientation)) {
/* 228 */       pageFormat.setOrientation(2);
/*     */     } 
/*     */     
/* 231 */     pageFormat.setPaper(paper);
/* 232 */     pageFormat = printerJob.validatePage(pageFormat);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 237 */     Boolean showPageFormat = (Boolean)this.hints.get(KEY_SHOW_PAGE_DIALOG);
/* 238 */     if (showPageFormat != null && showPageFormat.booleanValue()) {
/* 239 */       PageFormat tmpPageFormat = printerJob.pageDialog(pageFormat);
/* 240 */       if (tmpPageFormat == pageFormat) {
/*     */         return;
/*     */       }
/*     */ 
/*     */ 
/*     */       
/* 246 */       pageFormat = tmpPageFormat;
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 251 */     printerJob.setPrintable(this, pageFormat);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 257 */     Boolean showPrinterDialog = (Boolean)this.hints.get(KEY_SHOW_PRINTER_DIALOG);
/* 258 */     if (showPrinterDialog != null && showPrinterDialog.booleanValue() && 
/* 259 */       !printerJob.printDialog()) {
/*     */       return;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 267 */     printerJob.print();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int print(Graphics _g, PageFormat pageFormat, int pageIndex) {
/* 279 */     if (this.printedInputs == null) {
/* 280 */       this.printedInputs = new ArrayList(this.inputs);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 286 */     if (pageIndex >= this.printedInputs.size()) {
/* 287 */       this.curIndex = -1;
/* 288 */       if (this.theCtx != null)
/* 289 */         this.theCtx.dispose(); 
/* 290 */       this.userAgent.displayMessage("Done");
/* 291 */       return 1;
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 297 */     if (this.curIndex != pageIndex) {
/* 298 */       if (this.theCtx != null) {
/* 299 */         this.theCtx.dispose();
/*     */       }
/*     */ 
/*     */ 
/*     */       
/*     */       try {
/* 305 */         this.width = (int)pageFormat.getImageableWidth();
/* 306 */         this.height = (int)pageFormat.getImageableHeight();
/* 307 */         super.transcode((TranscoderInput)this.printedInputs.get(pageIndex), null);
/*     */         
/* 309 */         this.curIndex = pageIndex;
/*     */       } catch (TranscoderException e) {
/* 311 */         drawError(_g, e);
/* 312 */         return 0;
/*     */       } 
/*     */     } 
/*     */ 
/*     */     
/* 317 */     Graphics2D g = (Graphics2D)_g;
/* 318 */     g.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
/*     */     
/* 320 */     g.setRenderingHint(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BILINEAR);
/*     */     
/* 322 */     g.setRenderingHint(RenderingHintsKeyExt.KEY_TRANSCODING, "Printing");
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 328 */     AffineTransform t = g.getTransform();
/* 329 */     Shape clip = g.getClip();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 337 */     g.translate(pageFormat.getImageableX(), pageFormat.getImageableY());
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 342 */     g.transform(this.curTxf);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     try {
/* 348 */       this.root.paint(g);
/*     */     } catch (Exception e) {
/* 350 */       g.setTransform(t);
/* 351 */       g.setClip(clip);
/* 352 */       drawError(_g, e);
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 358 */     g.setTransform(t);
/* 359 */     g.setClip(clip);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 368 */     return 0;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void setImageSize(float docWidth, float docHeight) {
/* 380 */     Boolean scaleToPage = (Boolean)this.hints.get(KEY_SCALE_TO_PAGE);
/* 381 */     if (scaleToPage != null && !scaleToPage.booleanValue()) {
/* 382 */       float w = docWidth;
/* 383 */       float h = docHeight;
/* 384 */       if (this.hints.containsKey(SVGAbstractTranscoder.KEY_AOI)) {
/* 385 */         Rectangle2D aoi = (Rectangle2D)this.hints.get(SVGAbstractTranscoder.KEY_AOI);
/* 386 */         w = (float)aoi.getWidth();
/* 387 */         h = (float)aoi.getHeight();
/*     */       } 
/* 389 */       super.setImageSize(w, h);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 397 */   private void drawError(Graphics g, Exception e) { this.userAgent.displayError(e); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 426 */   public static final TranscodingHints.Key KEY_SHOW_PAGE_DIALOG = new BooleanKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 452 */   public static final TranscodingHints.Key KEY_SHOW_PRINTER_DIALOG = new BooleanKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 475 */   public static final TranscodingHints.Key KEY_PAGE_WIDTH = new LengthKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 497 */   public static final TranscodingHints.Key KEY_PAGE_HEIGHT = new LengthKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 519 */   public static final TranscodingHints.Key KEY_MARGIN_TOP = new LengthKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 541 */   public static final TranscodingHints.Key KEY_MARGIN_RIGHT = new LengthKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 563 */   public static final TranscodingHints.Key KEY_MARGIN_BOTTOM = new LengthKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 585 */   public static final TranscodingHints.Key KEY_MARGIN_LEFT = new LengthKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 607 */   public static final TranscodingHints.Key KEY_PAGE_ORIENTATION = new StringKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 631 */   public static final TranscodingHints.Key KEY_SCALE_TO_PAGE = new BooleanKey();
/*     */   
/*     */   public static final String USAGE = "java org.apache.batik.transcoder.print.PrintTranscoder <svgFileToPrint>";
/*     */ 
/*     */   
/*     */   public static void main(String[] args) throws Exception {
/* 637 */     if (args.length < 1) {
/* 638 */       System.err.println("java org.apache.batik.transcoder.print.PrintTranscoder <svgFileToPrint>");
/* 639 */       System.exit(0);
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 645 */     PrintTranscoder transcoder = new PrintTranscoder();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 652 */     setTranscoderFloatHint(transcoder, "language", SVGAbstractTranscoder.KEY_LANGUAGE);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 657 */     setTranscoderFloatHint(transcoder, "userStylesheet", SVGAbstractTranscoder.KEY_USER_STYLESHEET_URI);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 662 */     setTranscoderStringHint(transcoder, "xmlParserClassName", XMLAbstractTranscoder.KEY_XML_PARSER_CLASSNAME);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 667 */     setTranscoderBooleanHint(transcoder, "scaleToPage", KEY_SCALE_TO_PAGE);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 672 */     setTranscoderRectangleHint(transcoder, "aoi", SVGAbstractTranscoder.KEY_AOI);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 678 */     setTranscoderFloatHint(transcoder, "width", SVGAbstractTranscoder.KEY_WIDTH);
/*     */ 
/*     */     
/* 681 */     setTranscoderFloatHint(transcoder, "height", SVGAbstractTranscoder.KEY_HEIGHT);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 686 */     setTranscoderFloatHint(transcoder, "pixelToMm", SVGAbstractTranscoder.KEY_PIXEL_UNIT_TO_MILLIMETER);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 691 */     setTranscoderStringHint(transcoder, "pageOrientation", KEY_PAGE_ORIENTATION);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 696 */     setTranscoderFloatHint(transcoder, "pageWidth", KEY_PAGE_WIDTH);
/*     */ 
/*     */     
/* 699 */     setTranscoderFloatHint(transcoder, "pageHeight", KEY_PAGE_HEIGHT);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 704 */     setTranscoderFloatHint(transcoder, "marginTop", KEY_MARGIN_TOP);
/*     */ 
/*     */     
/* 707 */     setTranscoderFloatHint(transcoder, "marginRight", KEY_MARGIN_RIGHT);
/*     */ 
/*     */     
/* 710 */     setTranscoderFloatHint(transcoder, "marginBottom", KEY_MARGIN_BOTTOM);
/*     */ 
/*     */     
/* 713 */     setTranscoderFloatHint(transcoder, "marginLeft", KEY_MARGIN_LEFT);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 718 */     setTranscoderBooleanHint(transcoder, "showPageDialog", KEY_SHOW_PAGE_DIALOG);
/*     */ 
/*     */ 
/*     */     
/* 722 */     setTranscoderBooleanHint(transcoder, "showPrinterDialog", KEY_SHOW_PRINTER_DIALOG);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 730 */     for (int i = 0; i < args.length; i++) {
/* 731 */       transcoder.transcode(new TranscoderInput((new File(args[i])).toURL().toString()), null);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 738 */     transcoder.print();
/*     */     
/* 740 */     System.exit(0);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public static void setTranscoderFloatHint(Transcoder transcoder, String property, TranscodingHints.Key key) {
/* 746 */     String str = System.getProperty(property);
/* 747 */     if (str != null) {
/*     */       try {
/* 749 */         Float value = new Float(Float.parseFloat(str));
/* 750 */         transcoder.addTranscodingHint(key, value);
/*     */       } catch (NumberFormatException e) {
/* 752 */         handleValueError(property, str);
/*     */       } 
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public static void setTranscoderRectangleHint(Transcoder transcoder, String property, TranscodingHints.Key key) {
/* 760 */     String str = System.getProperty(property);
/* 761 */     if (str != null) {
/* 762 */       StringTokenizer st = new StringTokenizer(str, " ,");
/* 763 */       if (st.countTokens() != 4) {
/* 764 */         handleValueError(property, str);
/*     */       }
/*     */       
/*     */       try {
/* 768 */         String x = st.nextToken();
/* 769 */         String y = st.nextToken();
/* 770 */         String width = st.nextToken();
/* 771 */         String height = st.nextToken();
/* 772 */         Rectangle2D r = new Rectangle2D.Float(Float.parseFloat(x), Float.parseFloat(y), Float.parseFloat(width), Float.parseFloat(height));
/*     */ 
/*     */ 
/*     */         
/* 776 */         transcoder.addTranscodingHint(key, r);
/*     */       } catch (NumberFormatException e) {
/* 778 */         handleValueError(property, str);
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public static void setTranscoderBooleanHint(Transcoder transcoder, String property, TranscodingHints.Key key) {
/* 786 */     String str = System.getProperty(property);
/* 787 */     if (str != null) {
/* 788 */       Boolean value = "true".equalsIgnoreCase(str) ? Boolean.TRUE : Boolean.FALSE;
/* 789 */       transcoder.addTranscodingHint(key, value);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public static void setTranscoderStringHint(Transcoder transcoder, String property, TranscodingHints.Key key) {
/* 796 */     String str = System.getProperty(property);
/* 797 */     if (str != null) {
/* 798 */       transcoder.addTranscodingHint(key, str);
/*     */     }
/*     */   }
/*     */ 
/*     */   
/*     */   public static void handleValueError(String property, String value) {
/* 804 */     System.err.println("Invalid " + property + " value : " + value);
/* 805 */     System.exit(1);
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-transcoder.jar!\org\apache\batik\transcoder\print\PrintTranscoder.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */