/*     */ package org.apache.batik.transcoder.svg2svg;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.Writer;
/*     */ import java.util.Iterator;
/*     */ import java.util.LinkedList;
/*     */ import java.util.List;
/*     */ import org.apache.batik.xml.XMLUtilities;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class OutputManager
/*     */ {
/*     */   protected PrettyPrinter prettyPrinter;
/*     */   protected Writer writer;
/*     */   protected int level;
/*     */   protected StringBuffer margin;
/*     */   protected int line;
/*     */   protected int column;
/*     */   protected List xmlSpace;
/*     */   protected boolean canIndent;
/*     */   protected List startingLines;
/*     */   protected boolean lineAttributes;
/*     */   
/*     */   public OutputManager(PrettyPrinter pp, Writer w) {
/*  55 */     this.margin = new StringBuffer();
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  60 */     this.line = 1;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  70 */     this.xmlSpace = new LinkedList();
/*     */     
/*  72 */     this.xmlSpace.add(Boolean.FALSE);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  78 */     this.canIndent = true;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  83 */     this.startingLines = new LinkedList();
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  88 */     this.lineAttributes = false;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  96 */     this.prettyPrinter = pp;
/*  97 */     this.writer = w;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printCharacter(char c) throws IOException {
/* 104 */     if (c == '\n') {
/* 105 */       printNewline();
/*     */     } else {
/* 107 */       this.column++;
/* 108 */       this.writer.write(c);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printNewline() throws IOException {
/* 116 */     String nl = this.prettyPrinter.getNewline();
/* 117 */     for (int i = 0; i < nl.length(); i++) {
/* 118 */       this.writer.write(nl.charAt(i));
/*     */     }
/* 120 */     this.column = 0;
/* 121 */     this.line++;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printString(String s) throws IOException {
/* 128 */     for (int i = 0; i < s.length(); i++) {
/* 129 */       printCharacter(s.charAt(i));
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printCharacters(char[] ca) throws IOException {
/* 137 */     for (int i = 0; i < ca.length; i++) {
/* 138 */       printCharacter(ca[i]);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printSpaces(char[] text, boolean opt) throws IOException {
/* 148 */     if (this.prettyPrinter.getFormat()) {
/* 149 */       if (!opt) {
/* 150 */         printCharacter(' ');
/*     */       }
/*     */     } else {
/* 153 */       printCharacters(text);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printTopSpaces(char[] text) throws IOException {
/* 162 */     if (this.prettyPrinter.getFormat()) {
/* 163 */       int nl = newlines(text);
/* 164 */       for (int i = 0; i < nl; i++) {
/* 165 */         printNewline();
/*     */       }
/*     */     } else {
/* 168 */       printCharacters(text);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printComment(char[] text) throws IOException {
/* 177 */     if (this.prettyPrinter.getFormat()) {
/* 178 */       if (this.canIndent) {
/* 179 */         printNewline();
/* 180 */         printString(this.margin.toString());
/*     */       } 
/* 182 */       printString("<!--");
/* 183 */       if (this.column + text.length + 3 < this.prettyPrinter.getDocumentWidth()) {
/* 184 */         printCharacters(text);
/*     */       } else {
/* 186 */         formatText(text, this.margin.toString(), false);
/* 187 */         printCharacter(' ');
/*     */       } 
/* 189 */       if (this.column + 3 > this.prettyPrinter.getDocumentWidth()) {
/* 190 */         printNewline();
/* 191 */         printString(this.margin.toString());
/*     */       } 
/* 193 */       printString("-->");
/*     */     } else {
/* 195 */       printString("<!--");
/* 196 */       printCharacters(text);
/* 197 */       printString("-->");
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printXMLDecl(char[] space1, char[] space2, char[] space3, char[] version, char versionDelim, char[] space4, char[] space5, char[] space6, char[] encoding, char encodingDelim, char[] space7, char[] space8, char[] space9, char[] standalone, char standaloneDelim, char[] space10) throws IOException {
/* 218 */     printString("<?xml");
/*     */     
/* 220 */     printSpaces(space1, false);
/*     */     
/* 222 */     printString("version");
/*     */     
/* 224 */     if (space2 != null) {
/* 225 */       printSpaces(space2, true);
/*     */     }
/*     */     
/* 228 */     printCharacter('=');
/*     */     
/* 230 */     if (space3 != null) {
/* 231 */       printSpaces(space3, true);
/*     */     }
/*     */     
/* 234 */     printCharacter(versionDelim);
/* 235 */     printCharacters(version);
/* 236 */     printCharacter(versionDelim);
/*     */     
/* 238 */     if (space4 != null) {
/* 239 */       printSpaces(space4, false);
/*     */       
/* 241 */       if (encoding != null) {
/* 242 */         printString("encoding");
/*     */         
/* 244 */         if (space5 != null) {
/* 245 */           printSpaces(space5, true);
/*     */         }
/*     */         
/* 248 */         printCharacter('=');
/*     */         
/* 250 */         if (space6 != null) {
/* 251 */           printSpaces(space6, true);
/*     */         }
/*     */         
/* 254 */         printCharacter(encodingDelim);
/* 255 */         printCharacters(encoding);
/* 256 */         printCharacter(encodingDelim);
/*     */         
/* 258 */         if (space7 != null) {
/* 259 */           printSpaces(space7, (standalone == null));
/*     */         }
/*     */       } 
/*     */       
/* 263 */       if (standalone != null) {
/* 264 */         printString("standalone");
/*     */         
/* 266 */         if (space8 != null) {
/* 267 */           printSpaces(space8, true);
/*     */         }
/*     */         
/* 270 */         printCharacter('=');
/*     */         
/* 272 */         if (space9 != null) {
/* 273 */           printSpaces(space9, true);
/*     */         }
/*     */         
/* 276 */         printCharacter(standaloneDelim);
/* 277 */         printCharacters(standalone);
/* 278 */         printCharacter(standaloneDelim);
/*     */         
/* 280 */         if (space10 != null) {
/* 281 */           printSpaces(space10, true);
/*     */         }
/*     */       } 
/*     */     } 
/*     */     
/* 286 */     printString("?>");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printPI(char[] target, char[] space, char[] data) throws IOException {
/* 293 */     if (this.prettyPrinter.getFormat() && 
/* 294 */       this.canIndent) {
/* 295 */       printNewline();
/* 296 */       printString(this.margin.toString());
/*     */     } 
/*     */     
/* 299 */     printString("<?");
/* 300 */     printCharacters(target);
/* 301 */     printSpaces(space, false);
/* 302 */     printCharacters(data);
/* 303 */     printString("?>");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printDoctypeStart(char[] space1, char[] root, char[] space2, String externalId, char[] space3, char[] string1, char string1Delim, char[] space4, char[] string2, char string2Delim, char[] space5) throws IOException {
/* 318 */     if (this.prettyPrinter.getFormat()) {
/* 319 */       printString("<!DOCTYPE");
/*     */       
/* 321 */       printCharacter(' ');
/* 322 */       printCharacters(root);
/*     */       
/* 324 */       if (space2 != null) {
/* 325 */         printCharacter(' ');
/* 326 */         printString(externalId);
/* 327 */         printCharacter(' ');
/*     */         
/* 329 */         printCharacter(string1Delim);
/* 330 */         printCharacters(string1);
/* 331 */         printCharacter(string1Delim);
/*     */         
/* 333 */         if (space4 != null && 
/* 334 */           string2 != null) {
/* 335 */           if (this.column + string2.length + 3 > this.prettyPrinter.getDocumentWidth()) {
/*     */             
/* 337 */             printNewline();
/* 338 */             int i = 0;
/* 339 */             for (; i < this.prettyPrinter.getTabulationWidth(); 
/* 340 */               i++) {
/* 341 */               printCharacter(' ');
/*     */             }
/*     */           } else {
/* 344 */             printCharacter(' ');
/*     */           } 
/* 346 */           printCharacter(string2Delim);
/* 347 */           printCharacters(string2);
/* 348 */           printCharacter(string2Delim);
/* 349 */           printCharacter(' ');
/*     */         } 
/*     */       } 
/*     */     } else {
/*     */       
/* 354 */       printString("<!DOCTYPE");
/*     */       
/* 356 */       printSpaces(space1, false);
/* 357 */       printCharacters(root);
/*     */       
/* 359 */       if (space2 != null) {
/* 360 */         printSpaces(space2, false);
/* 361 */         printString(externalId);
/* 362 */         printSpaces(space3, false);
/*     */         
/* 364 */         printCharacter(string1Delim);
/* 365 */         printCharacters(string1);
/* 366 */         printCharacter(string1Delim);
/*     */         
/* 368 */         if (space4 != null) {
/* 369 */           printSpaces(space4, (string2 == null));
/*     */           
/* 371 */           if (string2 != null) {
/* 372 */             printCharacter(string2Delim);
/* 373 */             printCharacters(string2);
/* 374 */             printCharacter(string2Delim);
/*     */             
/* 376 */             if (space5 != null) {
/* 377 */               printSpaces(space5, true);
/*     */             }
/*     */           } 
/*     */         } 
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printDoctypeEnd(char[] space) throws IOException {
/* 389 */     if (space != null) {
/* 390 */       printSpaces(space, true);
/*     */     }
/* 392 */     printCharacter('>');
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printParameterEntityReference(char[] name) throws IOException {
/* 399 */     printCharacter('%');
/* 400 */     printCharacters(name);
/* 401 */     printCharacter(';');
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printEntityReference(char[] name, boolean first) throws IOException {
/* 409 */     if (this.prettyPrinter.getFormat() && this.xmlSpace.get(false) != Boolean.TRUE && first) {
/*     */ 
/*     */       
/* 412 */       printNewline();
/* 413 */       printString(this.margin.toString());
/*     */     } 
/* 415 */     printCharacter('&');
/* 416 */     printCharacters(name);
/* 417 */     printCharacter(';');
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printCharacterEntityReference(char[] code, boolean first, boolean preceedingSpace) throws IOException {
/* 426 */     if (this.prettyPrinter.getFormat() && this.xmlSpace.get(false) != Boolean.TRUE)
/*     */     {
/*     */       
/* 429 */       if (first) {
/* 430 */         printNewline();
/* 431 */         printString(this.margin.toString());
/* 432 */       } else if (preceedingSpace) {
/* 433 */         int endCol = this.column + code.length + 3;
/* 434 */         if (endCol > this.prettyPrinter.getDocumentWidth()) {
/* 435 */           printNewline();
/* 436 */           printString(this.margin.toString());
/*     */         } else {
/* 438 */           printCharacter(' ');
/*     */         } 
/*     */       } 
/*     */     }
/* 442 */     printString("&#");
/* 443 */     printCharacters(code);
/* 444 */     printCharacter(';');
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printElementStart(char[] name, List attributes, char[] space) throws IOException {
/* 452 */     this.xmlSpace.add(0, this.xmlSpace.get(0));
/*     */     
/* 454 */     this.startingLines.add(0, new Integer(this.line));
/*     */     
/* 456 */     if (this.prettyPrinter.getFormat() && 
/* 457 */       this.canIndent) {
/* 458 */       printNewline();
/* 459 */       printString(this.margin.toString());
/*     */     } 
/*     */     
/* 462 */     printCharacter('<');
/* 463 */     printCharacters(name);
/*     */     
/* 465 */     if (this.prettyPrinter.getFormat()) {
/* 466 */       Iterator it = attributes.iterator();
/* 467 */       if (it.hasNext()) {
/* 468 */         AttributeInfo ai = (AttributeInfo)it.next();
/*     */         
/* 470 */         if (ai.isAttribute("xml:space")) {
/* 471 */           this.xmlSpace.set(0, ai.value.equals("preserve") ? Boolean.TRUE : Boolean.FALSE);
/*     */         }
/*     */ 
/*     */ 
/*     */         
/* 476 */         printCharacter(' ');
/* 477 */         printCharacters(ai.name);
/* 478 */         printCharacter('=');
/* 479 */         printCharacter(ai.delimiter);
/* 480 */         printString(ai.value);
/* 481 */         printCharacter(ai.delimiter);
/*     */       } 
/* 483 */       while (it.hasNext()) {
/* 484 */         AttributeInfo ai = (AttributeInfo)it.next();
/*     */         
/* 486 */         if (ai.isAttribute("xml:space")) {
/* 487 */           this.xmlSpace.set(0, ai.value.equals("preserve") ? Boolean.TRUE : Boolean.FALSE);
/*     */         }
/*     */ 
/*     */ 
/*     */         
/* 492 */         int len = ai.name.length + ai.value.length() + 4;
/* 493 */         if (this.lineAttributes || len + this.column > this.prettyPrinter.getDocumentWidth()) {
/*     */           
/* 495 */           printNewline();
/* 496 */           printString(this.margin.toString());
/* 497 */           for (int i = 0; i < name.length + 2; i++) {
/* 498 */             printCharacter(' ');
/*     */           }
/*     */         } else {
/* 501 */           printCharacter(' ');
/*     */         } 
/* 503 */         printCharacters(ai.name);
/* 504 */         printCharacter('=');
/* 505 */         printCharacter(ai.delimiter);
/* 506 */         printString(ai.value);
/* 507 */         printCharacter(ai.delimiter);
/*     */       } 
/*     */     } else {
/* 510 */       Iterator it = attributes.iterator();
/* 511 */       while (it.hasNext()) {
/* 512 */         AttributeInfo ai = (AttributeInfo)it.next();
/*     */         
/* 514 */         if (ai.isAttribute("xml:space")) {
/* 515 */           this.xmlSpace.set(0, ai.value.equals("preserve") ? Boolean.TRUE : Boolean.FALSE);
/*     */         }
/*     */ 
/*     */ 
/*     */         
/* 520 */         printSpaces(ai.space, false);
/* 521 */         printCharacters(ai.name);
/*     */         
/* 523 */         if (ai.space1 != null) {
/* 524 */           printSpaces(ai.space1, true);
/*     */         }
/* 526 */         printCharacter('=');
/* 527 */         if (ai.space2 != null) {
/* 528 */           printSpaces(ai.space2, true);
/*     */         }
/*     */         
/* 531 */         printCharacter(ai.delimiter);
/* 532 */         printString(ai.value);
/* 533 */         printCharacter(ai.delimiter);
/*     */       } 
/*     */     } 
/*     */     
/* 537 */     if (space != null) {
/* 538 */       printSpaces(space, true);
/*     */     }
/* 540 */     this.level++;
/* 541 */     for (int i = 0; i < this.prettyPrinter.getTabulationWidth(); i++) {
/* 542 */       this.margin.append(' ');
/*     */     }
/* 544 */     this.canIndent = true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printElementEnd(char[] name, char[] space) throws IOException {
/* 551 */     for (int i = 0; i < this.prettyPrinter.getTabulationWidth(); i++) {
/* 552 */       this.margin.deleteCharAt(0);
/*     */     }
/* 554 */     this.level--;
/* 555 */     if (name != null) {
/* 556 */       if (this.prettyPrinter.getFormat() && 
/* 557 */         this.xmlSpace.get(false) != Boolean.TRUE && (this.line != ((Integer)this.startingLines.get(0)).intValue() || this.column + name.length + 3 >= this.prettyPrinter.getDocumentWidth())) {
/*     */ 
/*     */         
/* 560 */         printNewline();
/* 561 */         printString(this.margin.toString());
/*     */       } 
/*     */       
/* 564 */       printString("</");
/* 565 */       printCharacters(name);
/* 566 */       if (space != null) {
/* 567 */         printSpaces(space, true);
/*     */       }
/* 569 */       printCharacter('>');
/*     */     } else {
/* 571 */       printString("/>");
/*     */     } 
/* 573 */     this.startingLines.remove(0);
/* 574 */     this.xmlSpace.remove(0);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean printCharacterData(char[] data, boolean first, boolean preceedingSpace) throws IOException {
/* 584 */     if (!this.prettyPrinter.getFormat()) {
/* 585 */       printCharacters(data);
/* 586 */       return false;
/*     */     } 
/*     */     
/* 589 */     this.canIndent = true;
/* 590 */     if (isWhiteSpace(data)) {
/* 591 */       int nl = newlines(data);
/* 592 */       for (int i = 0; i < nl - 1; i++) {
/* 593 */         printNewline();
/*     */       }
/* 595 */       return true;
/*     */     } 
/*     */     
/* 598 */     if (this.xmlSpace.get(false) == Boolean.TRUE) {
/* 599 */       printCharacters(data);
/* 600 */       this.canIndent = false;
/* 601 */       return false;
/*     */     } 
/*     */     
/* 604 */     if (first) {
/* 605 */       printNewline();
/* 606 */       printString(this.margin.toString());
/*     */     } 
/* 608 */     return formatText(data, this.margin.toString(), preceedingSpace);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printCDATASection(char[] data) throws IOException {
/* 615 */     printString("<![CDATA[");
/* 616 */     printCharacters(data);
/* 617 */     printString("]]>");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printNotation(char[] space1, char[] name, char[] space2, String externalId, char[] space3, char[] string1, char string1Delim, char[] space4, char[] string2, char string2Delim, char[] space5) throws IOException {
/* 633 */     this.writer.write("<!NOTATION");
/* 634 */     printSpaces(space1, false);
/* 635 */     this.writer.write(name);
/* 636 */     printSpaces(space2, false);
/* 637 */     this.writer.write(externalId);
/* 638 */     printSpaces(space3, false);
/*     */     
/* 640 */     this.writer.write(string1Delim);
/* 641 */     this.writer.write(string1);
/* 642 */     this.writer.write(string1Delim);
/*     */     
/* 644 */     if (space4 != null) {
/* 645 */       printSpaces(space4, false);
/*     */       
/* 647 */       if (string2 != null) {
/* 648 */         this.writer.write(string2Delim);
/* 649 */         this.writer.write(string2);
/* 650 */         this.writer.write(string2Delim);
/*     */       } 
/*     */     } 
/* 653 */     if (space5 != null) {
/* 654 */       printSpaces(space5, true);
/*     */     }
/* 656 */     this.writer.write(62);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printAttlistStart(char[] space, char[] name) throws IOException {
/* 663 */     this.writer.write("<!ATTLIST");
/* 664 */     printSpaces(space, false);
/* 665 */     this.writer.write(name);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printAttlistEnd(char[] space) throws IOException {
/* 672 */     if (space != null) {
/* 673 */       printSpaces(space, false);
/*     */     }
/* 675 */     this.writer.write(62);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printAttName(char[] space1, char[] name, char[] space2) throws IOException {
/* 683 */     printSpaces(space1, false);
/* 684 */     this.writer.write(name);
/* 685 */     printSpaces(space2, false);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printEnumeration(List names) throws IOException {
/* 692 */     this.writer.write(40);
/*     */     
/* 694 */     Iterator it = names.iterator();
/* 695 */     NameInfo ni = (NameInfo)it.next();
/* 696 */     if (ni.space1 != null) {
/* 697 */       printSpaces(ni.space1, true);
/*     */     }
/*     */     
/* 700 */     this.writer.write(ni.name);
/*     */     
/* 702 */     if (ni.space2 != null) {
/* 703 */       printSpaces(ni.space2, true);
/*     */     }
/* 705 */     while (it.hasNext()) {
/* 706 */       this.writer.write(124);
/*     */       
/* 708 */       ni = (NameInfo)it.next();
/* 709 */       if (ni.space1 != null) {
/* 710 */         printSpaces(ni.space1, true);
/*     */       }
/*     */       
/* 713 */       this.writer.write(ni.name);
/*     */       
/* 715 */       if (ni.space2 != null) {
/* 716 */         printSpaces(ni.space2, true);
/*     */       }
/*     */     } 
/*     */     
/* 720 */     this.writer.write(41);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int newlines(char[] text) {
/* 727 */     int result = 0;
/* 728 */     for (int i = 0; i < text.length; i++) {
/* 729 */       if (text[i] == '\n') {
/* 730 */         result++;
/*     */       }
/*     */     } 
/* 733 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected boolean isWhiteSpace(char[] text) {
/* 740 */     for (int i = 0; i < text.length; i++) {
/* 741 */       if (!XMLUtilities.isXMLSpace(text[i])) {
/* 742 */         return false;
/*     */       }
/*     */     } 
/* 745 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected boolean formatText(char[] text, String margin, boolean preceedingSpace) throws IOException {
/* 753 */     int i = 0;
/* 754 */     boolean startsWithSpace = preceedingSpace;
/* 755 */     while (i < text.length) {
/*     */       
/* 757 */       while (i < text.length) {
/*     */ 
/*     */         
/* 760 */         if (!XMLUtilities.isXMLSpace(text[i]))
/*     */         
/*     */         { 
/*     */ 
/*     */ 
/*     */           
/* 766 */           StringBuffer sb = new StringBuffer();
/*     */           
/* 768 */           while (i < text.length && !XMLUtilities.isXMLSpace(text[i]))
/*     */           {
/*     */             
/* 771 */             sb.append(text[i++]);
/*     */           }
/* 773 */           if (sb.length() == 0) {
/* 774 */             return startsWithSpace;
/*     */           }
/* 776 */           if (startsWithSpace)
/*     */           
/* 778 */           { int endCol = this.column + sb.length();
/* 779 */             if (endCol >= this.prettyPrinter.getDocumentWidth() - 1) { if (margin.length() + sb.length() < this.prettyPrinter.getDocumentWidth() - 1 || margin.length() < this.column) {
/*     */ 
/*     */ 
/*     */                 
/* 783 */                 printNewline();
/* 784 */                 printString(margin); // Byte code: goto -> 196
/* 785 */               }  if (this.column > margin.length())
/*     */               {
/* 787 */                 printCharacter(' ');
/*     */               }
/*     */               
/* 790 */               printString(sb.toString());
/* 791 */               startsWithSpace = false; continue; }  // Byte code: goto -> 179 }  // Byte code: goto -> 196 }  startsWithSpace = true; i++;
/*     */       }  break;
/* 793 */     }  return startsWithSpace;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static class NameInfo
/*     */   {
/*     */     public char[] space1;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public char[] name;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public char[] space2;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public NameInfo(char[] sp1, char[] nm, char[] sp2) throws IOException {
/* 820 */       this.space1 = sp1;
/* 821 */       this.name = nm;
/* 822 */       this.space2 = sp2;
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static class AttributeInfo
/*     */   {
/*     */     public char[] space;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public char[] name;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public char[] space1;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public char[] space2;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public String value;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public char delimiter;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public boolean entityReferences;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public AttributeInfo(char[] sp, char[] n, char[] sp1, char[] sp2, String val, char delim, boolean entity) {
/* 871 */       this.space = sp;
/* 872 */       this.name = n;
/* 873 */       this.space1 = sp1;
/* 874 */       this.space2 = sp2;
/* 875 */       this.value = val;
/* 876 */       this.delimiter = delim;
/* 877 */       this.entityReferences = entity;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public boolean isAttribute(String s) {
/* 885 */       if (this.name.length == s.length()) {
/* 886 */         for (int i = 0; i < this.name.length; i++) {
/* 887 */           if (this.name[i] != s.charAt(i)) {
/* 888 */             return false;
/*     */           }
/*     */         } 
/* 891 */         return true;
/*     */       } 
/* 893 */       return false;
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-transcoder.jar!\org\apache\batik\transcoder\svg2svg\OutputManager.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */