/*     */ package org.apache.batik.transcoder.svg2svg;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.Reader;
/*     */ import java.io.StringReader;
/*     */ import java.io.StringWriter;
/*     */ import java.io.Writer;
/*     */ import org.apache.batik.dom.util.DOMUtilities;
/*     */ import org.apache.batik.transcoder.AbstractTranscoder;
/*     */ import org.apache.batik.transcoder.ErrorHandler;
/*     */ import org.apache.batik.transcoder.TranscoderException;
/*     */ import org.apache.batik.transcoder.TranscoderInput;
/*     */ import org.apache.batik.transcoder.TranscoderOutput;
/*     */ import org.apache.batik.transcoder.TranscodingHints;
/*     */ import org.apache.batik.transcoder.keys.BooleanKey;
/*     */ import org.apache.batik.transcoder.keys.IntegerKey;
/*     */ import org.apache.batik.transcoder.keys.StringKey;
/*     */ import org.w3c.dom.Document;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGTranscoder
/*     */   extends AbstractTranscoder
/*     */ {
/*  51 */   public static final ErrorHandler DEFAULT_ERROR_HANDLER = new ErrorHandler()
/*     */     {
/*  53 */       public void error(TranscoderException ex) throws TranscoderException { throw ex; }
/*     */ 
/*     */       
/*  56 */       public void fatalError(TranscoderException ex) throws TranscoderException { throw ex; }
/*     */ 
/*     */ 
/*     */ 
/*     */       
/*     */       public void warning(TranscoderException ex) throws TranscoderException {}
/*     */     };
/*     */ 
/*     */ 
/*     */   
/*  66 */   public static final TranscodingHints.Key KEY_NEWLINE = new NewlineKey();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  71 */   public static final NewlineValue VALUE_NEWLINE_CR = new NewlineValue("\r");
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  76 */   public static final NewlineValue VALUE_NEWLINE_CR_LF = new NewlineValue("\r\n");
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  81 */   public static final NewlineValue VALUE_NEWLINE_LF = new NewlineValue("\n");
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  86 */   public static final TranscodingHints.Key KEY_FORMAT = new BooleanKey();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  91 */   public static final Boolean VALUE_FORMAT_ON = Boolean.TRUE;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  96 */   public static final Boolean VALUE_FORMAT_OFF = Boolean.FALSE;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 101 */   public static final TranscodingHints.Key KEY_TABULATION_WIDTH = new IntegerKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 107 */   public static final TranscodingHints.Key KEY_DOCUMENT_WIDTH = new IntegerKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 113 */   public static final TranscodingHints.Key KEY_DOCTYPE = new DoctypeKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 119 */   public static final DoctypeValue VALUE_DOCTYPE_CHANGE = new DoctypeValue(0);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 125 */   public static final DoctypeValue VALUE_DOCTYPE_REMOVE = new DoctypeValue(1);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 131 */   public static final DoctypeValue VALUE_DOCTYPE_KEEP_UNCHANGED = new DoctypeValue(2);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 137 */   public static final TranscodingHints.Key KEY_PUBLIC_ID = new StringKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 143 */   public static final TranscodingHints.Key KEY_SYSTEM_ID = new StringKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 149 */   public static final TranscodingHints.Key KEY_XML_DECLARATION = new StringKey();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 156 */   public SVGTranscoder() { setErrorHandler(DEFAULT_ERROR_HANDLER); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void transcode(TranscoderInput input, TranscoderOutput output) throws TranscoderException {
/* 167 */     Reader r = input.getReader();
/* 168 */     Writer w = output.getWriter();
/*     */     
/* 170 */     if (r == null) {
/* 171 */       Document d = input.getDocument();
/* 172 */       if (d == null) {
/* 173 */         throw new Error("Reader or Document expected");
/*     */       }
/* 175 */       StringWriter sw = new StringWriter(1024);
/*     */       try {
/* 177 */         DOMUtilities.writeDocument(d, sw);
/*     */       } catch (IOException ioEx) {
/* 179 */         throw new Error("IO:" + ioEx.getMessage());
/*     */       } 
/* 181 */       r = new StringReader(sw.toString());
/*     */     } 
/* 183 */     if (w == null) {
/* 184 */       throw new Error("Writer expected");
/*     */     }
/* 186 */     prettyPrint(r, w);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void prettyPrint(Reader in, Writer out) throws TranscoderException {
/*     */     try {
/* 195 */       PrettyPrinter pp = new PrettyPrinter();
/* 196 */       NewlineValue nlv = (NewlineValue)this.hints.get(KEY_NEWLINE);
/* 197 */       if (nlv != null) {
/* 198 */         pp.setNewline(nlv.getValue());
/*     */       }
/* 200 */       Boolean b = (Boolean)this.hints.get(KEY_FORMAT);
/* 201 */       if (b != null) {
/* 202 */         pp.setFormat(b.booleanValue());
/*     */       }
/* 204 */       Integer i = (Integer)this.hints.get(KEY_TABULATION_WIDTH);
/* 205 */       if (i != null) {
/* 206 */         pp.setTabulationWidth(i.intValue());
/*     */       }
/* 208 */       i = (Integer)this.hints.get(KEY_DOCUMENT_WIDTH);
/* 209 */       if (i != null) {
/* 210 */         pp.setDocumentWidth(i.intValue());
/*     */       }
/* 212 */       DoctypeValue dtv = (DoctypeValue)this.hints.get(KEY_DOCTYPE);
/* 213 */       if (dtv != null) {
/* 214 */         pp.setDoctypeOption(dtv.getValue());
/*     */       }
/* 216 */       String s = (String)this.hints.get(KEY_PUBLIC_ID);
/* 217 */       if (s != null) {
/* 218 */         pp.setPublicId(s);
/*     */       }
/* 220 */       s = (String)this.hints.get(KEY_SYSTEM_ID);
/* 221 */       if (s != null) {
/* 222 */         pp.setSystemId(s);
/*     */       }
/*     */       
/* 225 */       s = (String)this.hints.get(KEY_XML_DECLARATION);
/* 226 */       if (s != null) {
/* 227 */         pp.setXMLDeclaration(s);
/*     */       }
/*     */       
/* 230 */       pp.print(in, out);
/* 231 */       out.flush();
/*     */     } catch (IOException e) {
/* 233 */       getErrorHandler().fatalError(new TranscoderException(e.getMessage()));
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class NewlineKey
/*     */     extends TranscodingHints.Key
/*     */   {
/* 242 */     public boolean isCompatibleValue(Object v) { return v instanceof SVGTranscoder.NewlineValue; }
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class NewlineValue
/*     */   {
/*     */     protected final String value;
/*     */ 
/*     */     
/* 252 */     protected NewlineValue(String val) { this.value = val; }
/*     */ 
/*     */     
/* 255 */     public String getValue() { return this.value; }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class DoctypeKey
/*     */     extends TranscodingHints.Key
/*     */   {
/* 264 */     public boolean isCompatibleValue(Object v) { return v instanceof SVGTranscoder.DoctypeValue; }
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class DoctypeValue
/*     */   {
/*     */     final int value;
/*     */ 
/*     */     
/* 274 */     protected DoctypeValue(int value) { this.value = value; }
/*     */ 
/*     */     
/* 277 */     public int getValue() { return this.value; }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-transcoder.jar!\org\apache\batik\transcoder\svg2svg\SVGTranscoder.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */