/*     */ package org.apache.batik.transcoder.wmf.tosvg;
/*     */ 
/*     */ import java.awt.Rectangle;
/*     */ import java.awt.Toolkit;
/*     */ import java.awt.geom.Rectangle2D;
/*     */ import java.io.DataInputStream;
/*     */ import java.io.IOException;
/*     */ import java.util.ArrayList;
/*     */ import java.util.List;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class AbstractWMFReader
/*     */ {
/*  39 */   public static final float PIXEL_PER_INCH = Toolkit.getDefaultToolkit().getScreenResolution();
/*  40 */   public static final float MM_PER_PIXEL = 25.4F / Toolkit.getDefaultToolkit().getScreenResolution();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  45 */   protected int xSign = 1;
/*  46 */   protected int ySign = 1;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected boolean isAldus = false;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected boolean isotropic = true;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  61 */   protected float scaleX = 1.0F;
/*  62 */   protected float scaleY = 1.0F;
/*  63 */   protected float scaleXY = 1.0F;
/*  64 */   protected int left = -1;
/*  65 */   protected int top = -1;
/*  66 */   protected int width = -1;
/*  67 */   protected int height = -1;
/*  68 */   protected int right = this.left + this.width;
/*  69 */   protected int bottom = this.top + this.height;
/*  70 */   protected int numObjects = 0; protected int inch; protected int vpW; protected int vpH; protected int vpX;
/*  71 */   protected List objectVector = new ArrayList(); protected int vpY; protected int mtType; protected int mtHeaderSize;
/*     */   protected int mtVersion;
/*     */   
/*     */   public AbstractWMFReader(int width, int height) {
/*  75 */     this();
/*  76 */     this.width = width;
/*  77 */     this.height = height;
/*     */   }
/*     */   protected int mtSize; protected int mtNoObjects; protected int mtMaxRecord; protected int mtNoParameters; protected int windowWidth; protected int windowHeight; public int lastObjectIdx;
/*     */   
/*     */   public AbstractWMFReader() {}
/*     */   
/*     */   protected short readShort(DataInputStream is) throws IOException {
/*  84 */     byte[] js = new byte[2];
/*  85 */     is.readFully(js);
/*  86 */     int iTemp = (0xFF & js[1]) << '\b';
/*  87 */     i = (short)(0xFFFF & iTemp);
/*  88 */     return (short)(i | 0xFF & js[0]);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int readInt(DataInputStream is) throws IOException {
/*  96 */     byte[] js = new byte[4];
/*  97 */     is.readFully(js);
/*  98 */     i = (0xFF & js[3]) << '\030';
/*  99 */     i |= (0xFF & js[2]) << '\020';
/* 100 */     i |= (0xFF & js[1]) << '\b';
/* 101 */     return 0xFF & js[0];
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 109 */   public float getViewportWidthUnits() { return this.vpW; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 116 */   public float getViewportHeightUnits() { return this.vpH; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 123 */   public float getViewportWidthInch() { return this.vpW / this.inch; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 130 */   public float getViewportHeightInch() { return this.vpH / this.inch; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 136 */   public float getPixelsPerUnit() { return PIXEL_PER_INCH / this.inch; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 143 */   public int getVpW() { return (int)(PIXEL_PER_INCH * this.vpW / this.inch); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 150 */   public int getVpH() { return (int)(PIXEL_PER_INCH * this.vpH / this.inch); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 157 */   public int getLeftUnits() { return this.left; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 164 */   public int getRightUnits() { return this.right; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 171 */   public int getTopUnits() { return this.top; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 178 */   public int getWidthUnits() { return this.width; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 185 */   public int getHeightUnits() { return this.height; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 192 */   public int getBottomUnits() { return this.bottom; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 199 */   public int getMetaFileUnitsPerInch() { return this.inch; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 211 */   public Rectangle getRectangleUnits() { return new Rectangle(this.left, this.top, this.width, this.height); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Rectangle2D getRectanglePixel() {
/* 218 */     float _left = PIXEL_PER_INCH * this.left / this.inch;
/* 219 */     float _right = PIXEL_PER_INCH * this.right / this.inch;
/* 220 */     float _top = PIXEL_PER_INCH * this.top / this.inch;
/* 221 */     float _bottom = PIXEL_PER_INCH * this.bottom / this.inch;
/*     */     
/* 223 */     return new Rectangle2D.Float(_left, _top, _right - _left, _bottom - _top);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Rectangle2D getRectangleInch() {
/* 231 */     float _left = this.left / this.inch;
/* 232 */     float _right = this.right / this.inch;
/* 233 */     float _top = this.top / this.inch;
/* 234 */     float _bottom = this.bottom / this.inch;
/*     */     
/* 236 */     return new Rectangle2D.Float(_left, _top, _right - _left, _bottom - _top);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 244 */   public int getWidthPixels() { return (int)(PIXEL_PER_INCH * this.width / this.inch); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 250 */   public float getUnitsToPixels() { return PIXEL_PER_INCH / this.inch; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 256 */   public float getVpWFactor() { return PIXEL_PER_INCH * this.width / this.inch / this.vpW; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 262 */   public float getVpHFactor() { return PIXEL_PER_INCH * this.height / this.inch / this.vpH; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 268 */   public int getHeightPixels() { return (int)(PIXEL_PER_INCH * this.height / this.inch); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 275 */   public int getXSign() { return this.xSign; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 282 */   public int getYSign() { return this.ySign; }
/*     */ 
/*     */ 
/*     */   
/* 286 */   protected void setReading(boolean state) { this.bReading = state; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 292 */   public boolean isReading() { return this.bReading; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public abstract void reset();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected abstract boolean readRecords(DataInputStream paramDataInputStream) throws IOException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void read(DataInputStream is) throws IOException {
/* 358 */     reset();
/*     */     
/* 360 */     setReading(true);
/* 361 */     int dwIsAldus = readInt(is);
/* 362 */     if (dwIsAldus == -1698247209) {
/*     */       
/* 364 */       int key = dwIsAldus;
/* 365 */       this.isAldus = true;
/* 366 */       readShort(is);
/* 367 */       this.left = readShort(is);
/* 368 */       this.top = readShort(is);
/* 369 */       this.right = readShort(is);
/* 370 */       this.bottom = readShort(is);
/* 371 */       this.inch = readShort(is);
/* 372 */       int reserved = readInt(is);
/* 373 */       short checksum = readShort(is);
/*     */ 
/*     */       
/* 376 */       if (this.left > this.right) {
/* 377 */         int _i = this.right;
/* 378 */         this.right = this.left;
/* 379 */         this.left = _i;
/* 380 */         this.xSign = -1;
/*     */       } 
/* 382 */       if (this.top > this.bottom) {
/* 383 */         int _i = this.bottom;
/* 384 */         this.bottom = this.top;
/* 385 */         this.top = _i;
/* 386 */         this.ySign = -1;
/*     */       } 
/*     */       
/* 389 */       this.width = this.right - this.left;
/* 390 */       this.height = this.bottom - this.top;
/*     */ 
/*     */       
/* 393 */       this.mtType = readShort(is);
/* 394 */       this.mtHeaderSize = readShort(is);
/*     */     } else {
/*     */       
/* 397 */       this.mtType = dwIsAldus << 16 >> 16;
/* 398 */       this.mtHeaderSize = dwIsAldus >> 16;
/*     */     } 
/*     */     
/* 401 */     this.mtVersion = readShort(is);
/* 402 */     this.mtSize = readInt(is);
/* 403 */     this.mtNoObjects = readShort(is);
/* 404 */     this.mtMaxRecord = readInt(is);
/* 405 */     this.mtNoParameters = readShort(is);
/*     */     
/* 407 */     this.numObjects = this.mtNoObjects;
/* 408 */     List tempList = new ArrayList(this.numObjects);
/* 409 */     for (int i = 0; i < this.numObjects; i++) {
/* 410 */       tempList.add(new GdiObject(i, false));
/*     */     }
/* 412 */     this.objectVector.addAll(tempList);
/*     */     
/* 414 */     boolean ret = readRecords(is);
/* 415 */     is.close();
/* 416 */     if (!ret) throw new IOException("Unhandled exception while reading records"); 
/*     */   }
/*     */   
/*     */   public int addObject(int type, Object obj) {
/* 420 */     int startIdx = 0;
/*     */ 
/*     */ 
/*     */     
/* 424 */     for (int i = startIdx; i < this.numObjects; i++) {
/* 425 */       GdiObject gdi = (GdiObject)this.objectVector.get(i);
/* 426 */       if (!gdi.used) {
/* 427 */         gdi.Setup(type, obj);
/* 428 */         this.lastObjectIdx = i;
/*     */         
/*     */         break;
/*     */       } 
/*     */     } 
/* 433 */     return this.lastObjectIdx;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int addObjectAt(int type, Object obj, int idx) {
/* 445 */     if (idx == 0 || idx > this.numObjects) {
/* 446 */       addObject(type, obj);
/* 447 */       return this.lastObjectIdx;
/*     */     } 
/* 449 */     this.lastObjectIdx = idx;
/* 450 */     for (int i = 0; i < this.numObjects; i++) {
/* 451 */       GdiObject gdi = (GdiObject)this.objectVector.get(i);
/* 452 */       if (i == idx) {
/* 453 */         gdi.Setup(type, obj);
/*     */         
/*     */         break;
/*     */       } 
/*     */     } 
/* 458 */     return idx;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 465 */   public GdiObject getObject(int idx) { return (GdiObject)this.objectVector.get(idx); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 472 */   public int getNumObjects() { return this.numObjects; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-transcoder.jar!\org\apache\batik\transcoder\wmf\tosvg\AbstractWMFReader.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */