/*     */ package org.apache.batik.transcoder.wmf.tosvg;
/*     */ 
/*     */ import java.awt.Dimension;
/*     */ import java.io.BufferedInputStream;
/*     */ import java.io.DataInputStream;
/*     */ import java.io.File;
/*     */ import java.io.FileOutputStream;
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.net.MalformedURLException;
/*     */ import java.net.URL;
/*     */ import org.apache.batik.svggen.SVGGraphics2D;
/*     */ import org.apache.batik.transcoder.ToSVGAbstractTranscoder;
/*     */ import org.apache.batik.transcoder.TranscoderException;
/*     */ import org.apache.batik.transcoder.TranscoderInput;
/*     */ import org.apache.batik.transcoder.TranscoderOutput;
/*     */ import org.w3c.dom.Document;
/*     */ import org.w3c.dom.Element;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class WMFTranscoder
/*     */   extends ToSVGAbstractTranscoder
/*     */ {
/*     */   public static final String WMF_EXTENSION = ".wmf";
/*     */   public static final String SVG_EXTENSION = ".svg";
/*     */   
/*     */   public void transcode(TranscoderInput input, TranscoderOutput output) throws TranscoderException {
/*     */     int j, i;
/*     */     float f2, f1;
/* 111 */     DataInputStream is = getCompatibleInput(input);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 116 */     WMFRecordStore currentStore = new WMFRecordStore();
/*     */     try {
/* 118 */       currentStore.read(is);
/*     */     } catch (IOException e) {
/* 120 */       this.handler.fatalError(new TranscoderException(e));
/*     */ 
/*     */       
/*     */       return;
/*     */     } 
/*     */ 
/*     */     
/* 127 */     float conv = 1.0F;
/*     */     
/* 129 */     if (this.hints.containsKey(ToSVGAbstractTranscoder.KEY_INPUT_WIDTH)) {
/* 130 */       f1 = ((Integer)this.hints.get(ToSVGAbstractTranscoder.KEY_INPUT_WIDTH)).intValue();
/* 131 */       f2 = ((Integer)this.hints.get(ToSVGAbstractTranscoder.KEY_INPUT_HEIGHT)).intValue();
/*     */     } else {
/* 133 */       f1 = currentStore.getWidthPixels();
/* 134 */       f2 = currentStore.getHeightPixels();
/*     */     } 
/* 136 */     float width = f1;
/* 137 */     float height = f2;
/*     */ 
/*     */     
/* 140 */     if (this.hints.containsKey(ToSVGAbstractTranscoder.KEY_WIDTH)) {
/* 141 */       width = ((Float)this.hints.get(ToSVGAbstractTranscoder.KEY_WIDTH)).floatValue();
/* 142 */       conv = width / f1;
/* 143 */       height = height * width / f1;
/*     */     } 
/*     */ 
/*     */     
/* 147 */     int xOffset = 0;
/* 148 */     int yOffset = 0;
/* 149 */     if (this.hints.containsKey(ToSVGAbstractTranscoder.KEY_XOFFSET)) {
/* 150 */       xOffset = ((Integer)this.hints.get(ToSVGAbstractTranscoder.KEY_XOFFSET)).intValue();
/*     */     }
/* 152 */     if (this.hints.containsKey(ToSVGAbstractTranscoder.KEY_YOFFSET)) {
/* 153 */       yOffset = ((Integer)this.hints.get(ToSVGAbstractTranscoder.KEY_YOFFSET)).intValue();
/*     */     }
/*     */ 
/*     */     
/* 157 */     float sizeFactor = currentStore.getUnitsToPixels() * conv;
/*     */     
/* 159 */     int vpX = (int)(currentStore.getVpX() * sizeFactor);
/* 160 */     int vpY = (int)(currentStore.getVpY() * sizeFactor);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 165 */     if (this.hints.containsKey(ToSVGAbstractTranscoder.KEY_INPUT_WIDTH)) {
/* 166 */       i = (int)(((Integer)this.hints.get(ToSVGAbstractTranscoder.KEY_INPUT_WIDTH)).intValue() * conv);
/* 167 */       j = (int)(((Integer)this.hints.get(ToSVGAbstractTranscoder.KEY_INPUT_HEIGHT)).intValue() * conv);
/*     */     } else {
/*     */       
/* 170 */       i = (int)(currentStore.getWidthUnits() * sizeFactor);
/* 171 */       j = (int)(currentStore.getHeightUnits() * sizeFactor);
/*     */     } 
/*     */ 
/*     */     
/* 175 */     WMFPainter painter = new WMFPainter(currentStore, xOffset, yOffset, conv);
/*     */ 
/*     */     
/* 178 */     Document doc = createDocument(output);
/* 179 */     this.svgGenerator = new SVGGraphics2D(doc);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 185 */     this.svgGenerator.getGeneratorContext().setPrecision(4);
/*     */     
/* 187 */     painter.paint(this.svgGenerator);
/*     */     
/* 189 */     this.svgGenerator.setSVGCanvasSize(new Dimension(i, j));
/*     */     
/* 191 */     Element svgRoot = this.svgGenerator.getRoot();
/*     */     
/* 193 */     svgRoot.setAttributeNS(null, "viewBox", String.valueOf(vpX) + ' ' + vpY + ' ' + i + ' ' + j);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 198 */     writeSVGToOutput(this.svgGenerator, svgRoot, output);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private DataInputStream getCompatibleInput(TranscoderInput input) throws TranscoderException {
/* 208 */     if (input == null) {
/* 209 */       this.handler.fatalError(new TranscoderException(String.valueOf(65280)));
/*     */     }
/*     */ 
/*     */     
/* 213 */     InputStream in = input.getInputStream();
/* 214 */     if (in != null) {
/* 215 */       return new DataInputStream(new BufferedInputStream(in));
/*     */     }
/*     */ 
/*     */     
/* 219 */     String uri = input.getURI();
/* 220 */     if (uri != null) {
/*     */       try {
/* 222 */         URL url = new URL(uri);
/* 223 */         in = url.openStream();
/* 224 */         return new DataInputStream(new BufferedInputStream(in));
/*     */       } catch (MalformedURLException e) {
/* 226 */         this.handler.fatalError(new TranscoderException(e));
/*     */       } catch (IOException e) {
/* 228 */         this.handler.fatalError(new TranscoderException(e));
/*     */       } 
/*     */     }
/*     */     
/* 232 */     this.handler.fatalError(new TranscoderException(String.valueOf(65281)));
/* 233 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void main(String[] args) throws TranscoderException {
/* 243 */     if (args.length < 1) {
/* 244 */       System.out.println("Usage : WMFTranscoder.main <file 1> ... <file n>");
/* 245 */       System.exit(1);
/*     */     } 
/*     */     
/* 248 */     WMFTranscoder transcoder = new WMFTranscoder();
/* 249 */     int nFiles = args.length;
/*     */     
/* 251 */     for (int i = 0; i < nFiles; i++) {
/* 252 */       String fileName = args[i];
/* 253 */       if (!fileName.toLowerCase().endsWith(".wmf")) {
/* 254 */         System.err.println(args[i] + " does not have the " + ".wmf" + " extension. It is ignored");
/*     */       } else {
/*     */         
/* 257 */         System.out.print("Processing : " + args[i] + "...");
/* 258 */         String outputFileName = fileName.substring(0, fileName.toLowerCase().indexOf(".wmf")) + ".svg";
/* 259 */         File inputFile = new File(fileName);
/* 260 */         File outputFile = new File(outputFileName);
/*     */         try {
/* 262 */           TranscoderInput input = new TranscoderInput(inputFile.toURL().toString());
/* 263 */           TranscoderOutput output = new TranscoderOutput(new FileOutputStream(outputFile));
/* 264 */           transcoder.transcode(input, output);
/*     */         } catch (MalformedURLException e) {
/* 266 */           throw new TranscoderException(e);
/*     */         } catch (IOException e) {
/* 268 */           throw new TranscoderException(e);
/*     */         } 
/* 270 */         System.out.println(".... Done");
/*     */       } 
/*     */     } 
/*     */     
/* 274 */     System.exit(0);
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-transcoder.jar!\org\apache\batik\transcoder\wmf\tosvg\WMFTranscoder.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */